@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20250829';
+our $VERSION = '0.20250930';
 
-# Table last modified: 2025-08-29
+# Table last modified: 2025-09-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -18,7 +18,7 @@ our %ZIP_TABLE = (
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
     '013' => '(?:(?:8(?:5(?:92|0[1-4])|60[129])|0498))',
-    '014' => '(?:(?:0(?:39[2-4]|[25]92)|8(?:50|6[01])1|1(?:192|298)))',
+    '014' => '(?:(?:0(?:39[2-48]|[25]92)|8(?:50|6[01])1|1(?:192|298)))',
     '015' => '(?:(?:8(?:5(?:30|43|67|85|1[015]|5[58]|0[15])|6(?:[24]2|11|30|66|0[12]|8[68]))|0295))',
     '016' => '(?:8(?:5(?:01|55)|60[12]))',
     '017' => '(?:(?:8(?:5(?:10|67|85|5[05])|686)|029[23]))',
@@ -114,7 +114,7 @@ our %ZIP_TABLE = (
     '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[2358]|3[1-3689]|0[267]|1[125-8]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|0[6-8]|1[2-6]|2[235]|3[36])|408|807))',
-    '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
+    '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|0[126-8]|2[125]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
@@ -129,7 +129,7 @@ our %ZIP_TABLE = (
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|5[015]|3[03]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
-    '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
+    '134' => '(?:8(?:5(?:[15]5|[24]0|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
     '135' => '(?:8(?:5(?:48|3[0-358]|2[1-357]|7[57]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|3(?:[245]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|6(?:68|0[28]|2[0-25]|5[09]|3[0-29]|7[078]|1[04-9])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|080))',
     '136' => '(?:8(?:5(?:60|3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
@@ -173,7 +173,7 @@ our %ZIP_TABLE = (
     '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|70|85|1[1-469]|2[124-689]|5[013]|3[02469]|4[0189]|0[1256])|70[1-35-7]))',
     '184' => '(?:8(?:5(?:[34]3|22|95|1[015]|5[58]|7[57]|0[1-58]|8[1458])|795))',
-    '185' => '(?:8(?:5(?:[24]0|33|6[27]|0[126]|1[01])|601|795))',
+    '185' => '(?:8(?:5(?:[124]0|33|6[27]|0[126])|601|795))',
     '186' => '(?:8(?:6(?:50|0[1-3]|1[19]|8[068]|6[68])|5(?:19|85|0[15])|79[78]|001))',
     '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
@@ -415,7 +415,7 @@ our %ZIP_TABLE = (
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|4[05]|8[08]|0[1-37]|1[0-2579]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
     '442' => '(?:8(?:5(?:20|3[0-358]|0[1-35-79]|6[169]|5[058]|1[0-35-8]|7[35-7]|8[015-8]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:[05]5|88)|6[01]1)|019[2-4]))',
-    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
+    '444' => '(?:(?:8(?:5(?:77|90|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|2[0-356]|1[124578]|5[058]|0[1-8]|8[58]|3[035])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:1[0-2]|0[1-3578])|6(?:[18]0|0[1358])))',
@@ -718,7 +718,7 @@ our %ZIP_TABLE = (
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
-    '760' => '(?:8(?:5(?:90|5[0-2457-9]|3[0346-9]|1[1-8]|4[25-7]|2[0-57]|6[0-246-9]|8[0235689]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
+    '760' => '(?:8(?:5(?:90|5[0-2457-9]|3[0346-9]|1[1-8]|4[25-7]|2[0-57]|6[0-246-9]|8[0235689]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|2[013-5]|5[05]|1[0458]|4[48]|0[13478])))',
     '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601|777)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:50|1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:0[1-478]|1[0-368])|60[358]))',
@@ -919,7 +919,7 @@ our %ZIP_TABLE = (
     '960' => '(?:(?:8(?:5(?:75|4[06]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|0[1-35-9]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
-    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[078]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[6-8])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
+    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[078]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[2578]|29[6-8])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
     '965' => '(?:8(?:5(?:[347]0|67|0[1-6]|8[058]|2[02]|5[08]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
